stockbot package
================

Subpackages
-----------

.. toctree::

    stockbot.algo

Submodules
----------

stockbot.core module
--------------------

.. automodule:: stockbot.core
    :members:
    :undoc-members:
    :show-inheritance:

stockbot.marketdata module
--------------------------

.. automodule:: stockbot.marketdata
    :members:
    :undoc-members:
    :show-inheritance:

stockbot.portfolio module
-------------------------

.. automodule:: stockbot.portfolio
    :members:
    :undoc-members:
    :show-inheritance:

stockbot.sources module
-----------------------

.. automodule:: stockbot.sources
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: stockbot
    :members:
    :undoc-members:
    :show-inheritance:
